lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Tue, 30 May 2017 13:29:32 +0200
From:   Peter Zijlstra <peterz@...radead.org>
To:     Daniel Bristot de Oliveira <bristot@...hat.com>
Cc:     linux-kernel@...r.kernel.org, Xunlei Pang <xpang@...hat.com>,
        Ingo Molnar <mingo@...hat.com>,
        Juri Lelli <juri.lelli@....com>,
        Steven Rostedt <rostedt@...dmis.org>,
        Luca Abeni <luca.abeni@...tannapisa.it>,
        Tommaso Cucinotta <tommaso.cucinotta@...up.it>,
        Romulo Silva de Oliveira <romulo.deoliveira@...c.br>
Subject: Re: [PATCH V2 2/2] sched/deadline: Use the revised wakeup rule for
 suspending constrained dl tasks

On Mon, May 29, 2017 at 04:24:03PM +0200, Daniel Bristot de Oliveira wrote:
> +/*
> + * Regarding the deadline, a task with implicit deadline has a relative
> + * deadline == relative period. A task with constrained deadline has a
> + * relative deadline <= relative period.
> + *
> + * Linux supports constrained deadline tasks. However, there are some
> + * restrictions applied only for tasks with constrained deadline which are
> + * not implicit deadline tasks. See update_dl_entity() to know more about
> + * such restrictions.
> + *
> + * The dl_is_constrained() returns true if the task has a constrained but
> + * not implicit deadline.
> + */
> +static inline bool dl_is_constrained(struct sched_dl_entity *dl_se)
> +{
> +	return dl_se->dl_deadline < dl_se->dl_period;
> +}

OK, given that:

implicit    - deadline == period
constrained - deadline <= period

and thus constrained can still be implicit, our function
dl_is_constrained() is wrong.

I've replaced the above with dl_is_implicit().

--- a/kernel/sched/deadline.c
+++ b/kernel/sched/deadline.c
@@ -740,19 +740,17 @@ update_dl_revised_wakeup(struct sched_dl
 /*
  * Regarding the deadline, a task with implicit deadline has a relative
  * deadline == relative period. A task with constrained deadline has a
- * relative deadline < relative period.
+ * relative deadline <= relative period.
  *
- * We supports constrained deadline tasks. However, there are some
- * restrictions applied only for tasks with constrained deadline which are
- * not implicit deadline tasks. See update_dl_entity() to know more about
- * such restrictions.
+ * We support constrained deadline tasks. However, there are some restrictions
+ * applied only for tasks which do not have an implicit deadline. See
+ * update_dl_entity() to know more about such restrictions.
  *
  * The dl_is_constrained() returns true if the task has a constrained
  * (not implicit) deadline.
  */
-static inline bool dl_is_constrained(struct sched_dl_entity *dl_se)
+static inline bool dl_is_implicit(struct sched_dl_entity *dl_se)
 {
-	return dl_se->dl_deadline < dl_se->dl_period;
+	return dl_se->dl_deadline == dl_se->dl_period;
 }
 
 /*
@@ -794,7 +792,7 @@ static void update_dl_entity(struct sche
 	if (dl_time_before(dl_se->deadline, rq_clock(rq)) ||
 	    dl_entity_overflow(dl_se, pi_se, rq_clock(rq))) {
 
-		if (unlikely(dl_is_constrained(dl_se) &&
+		if (unlikely(!dl_is_implicit(dl_se) &&
 			     !dl_time_before(dl_se->deadline, rq_clock(rq)) &&
 			     !dl_se->dl_boosted)){
 			update_dl_revised_wakeup(dl_se, rq);
@@ -1386,7 +1384,7 @@ static void enqueue_task_dl(struct rq *r
 	 * If that is the case, the task will be throttled and
 	 * the replenishment timer will be set to the next period.
 	 */
-	if (!p->dl.dl_throttled && dl_is_constrained(&p->dl))
+	if (!p->dl.dl_throttled && !dl_is_implicit(&p->dl))
 		dl_check_constrained_dl(&p->dl);
 
 	if (p->on_rq == TASK_ON_RQ_MIGRATING || flags & ENQUEUE_RESTORE) {
@@ -740,19 +740,17 @@ update_dl_revised_wakeup(struct sched_dl
  *
- * The dl_is_constrained() returns true if the task has a constrained
- * (not implicit) deadline.
+ * The dl_is_implicit() returns true if the task has an implicit deadline.
  */

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ